@@ -1,10 +1,8 @@
-from __future__ import print_function, division, absolute_import
-from fontTools.misc.py23 import *
 import logging
 from fontTools.misc.loggingTools import configLogger
 
 log = logging.getLogger(__name__)
 
-version = __version__ = "3.21.2"
+version = __version__ = "4.44.1"
 
 __all__ = ["version", "log", "configLogger"]
